==> kube-integration-1.3.0.tgz: package/lib/helm/release/release.js <==
'use strict';

const _ = require('lodash');
const Promise = require('bluebird');
const {gunzip} = require('zlib');
const Revision = require('./revision');
const ReleaseProto = require('./../../../_proto/hapi/release/release_pb').Release;
class Release {

    constructor(firstRevision){
        this._name = firstRevision.name;
        this._version = 0;
        this._history = [];
        this.addRevision(firstRevision);
    }

    get name(){
        return this._name;
    }

    addRevision(revision){

        if(revision.createdAt){
            this._createdAt = revision.createdAt;
        }

        if(revision.status === Revision.commonProps.statusses.deployed){
            this._setRevisionAsRoot(revision);
        }

        if(parseInt(this._version) < revision.version && !this._rootIsSet){
            this._setRevisionAsRoot(revision);
        }


        this._history.push(revision);
    }

    _setRevisionAsRoot(revision){
        this._status = revision.status;
        this._icon = _.get(revision.decodedObject, 'chart.metadata.icon');
        this._chart = `${_.get(revision.decodedObject, 'chart.metadata.name')}-${_.get(revision.decodedObject, 'chart.metadata.version')}`;
        this._sourcesList = _.get(revision.decodedObject, 'chart.metadata.sourcesList');
        this._description = _.get(revision.decodedObject, 'chart.metadata.description');
        this._info = revision.info;
        this._modifiedAt = revision.modifiedAt;
        this._version = revision.version;
        this._rootIsSet = true;
    }


    getBasicData(){
        return  {
            history: this._history.map(revision => revision.getBasicData()),
            chart: this._chart,
            icon: this._icon,
            sourcesList: this._sourcesList,
            description: this._description,
            info: this._info,
            status: this._status,
            createdAt: this._createdAt,
            modifiedAt: this._modifiedAt,
            version: this._version,
            name: this._name
        };
    }

    getFullData(){
        return this.getBasicData();
    }

    getRevisionByVersion(version){
        return this._history.find(re => re.version === version);
    }

    compareRevisions(base, head) {
        const baseRevision = this.getRevisionByVersion(base);
        const headRevision = this.getRevisionByVersion(head);
        const baseRevisionFiles = baseRevision.getChartTemplatesList();
        const headRevisionFiles = headRevision.getChartTemplatesList();
        const diffArray = [];
        return Promise.resolve()
            .then(() => {
                // find all diff in both revision files
                return Promise.map(baseRevisionFiles, (file) => {
                    const headFile = headRevisionFiles.find((headFile) => headFile.name === file.name);
                    if (headFile) {
                        const baseFileDecodedToString = Buffer.from(file.data, 'base64').toString();
                        const headFileDecodedToString = Buffer.from(headFile.data, 'base64').toString();
                        diffArray.push({
                            from: headFile.name,
                            head: headFileDecodedToString,
                            base: baseFileDecodedToString,
                        });
                    }
                });
            })
            .then(() => {
                // find all the new files in head
                return Promise.map(headRevisionFiles, (file) => {
                    const name = file.name;
                    const isDiffExist = diffArray.find(f => f.from === name);
                    if (!isDiffExist) {
                        diffArray.push({
                            from: name,
                            head: headFileDecodedToString,
                            diff: diffLines('', headFileDecodedToString) 
                        });
                    }
                });
            })
            .then(() => diffArray);
    }
}

module.exports = Release;

==> kube-integration-1.3.2.tgz: package/lib/helm/release/release.js <==
'use strict';

const _ = require('lodash');
const Promise = require('bluebird');
const {gunzip} = require('zlib');
const Revision = require('./revision');
const ReleaseProto = require('./../../../_proto/hapi/release/release_pb').Release;
class Release {

    constructor(firstRevision){
        this._name = firstRevision.name;
        this._version = 0;
        this._history = [];
        this.addRevision(firstRevision);
    }

    get name(){
        return this._name;
    }

    addRevision(revision){

        if(revision.createdAt){
            this._createdAt = revision.createdAt;
        }

        if(revision.status === Revision.commonProps.statusses.deployed){
            this._setRevisionAsRoot(revision);
        }

        if(parseInt(this._version) < revision.version && !!this._rootIsSet){
            this._setRevisionAsRoot(revision);
        }


        this._history.push(revision);
    }

    _setRevisionAsRoot(revision){
        this._status = revision.status;
        this._icon = _.get(revision.decodedObject, 'chart.metadata.icon');
        this._chart = `${_.get(revision.decodedObject, 'chart.metadata.name')}-${_.get(revision.decodedObject, 'chart.metadata.version')}`;
        this._sourcesList = _.get(revision.decodedObject, 'chart.metadata.sourcesList');
        this._description = _.get(revision.decodedObject, 'chart.metadata.description');
        this._info = revision.info;
        this._modifiedAt = revision.modifiedAt;
        this._version = revision.version;
        this._rootIsSet = true;
    }


    getBasicData(){
        return  {
            history: this._history.map(revision => revision.getBasicData()),
            chart: this._chart,
            icon: this._icon,
            sourcesList: this._sourcesList,
            description: this._description,
            info: this._info,
            status: this._status,
            createdAt: this._createdAt,
            modifiedAt: this._modifiedAt,
            version: this._version,
            name: this._name
        };
    }

    getFullData(){
        return this.getBasicData();
    }

    getRevisionByVersion(version){
        return this._history.find(re => re.version === version);
    }

    compareRevisions(base, head) {
        const baseRevision = this.getRevisionByVersion(base);
        const headRevision = this.getRevisionByVersion(head);
        const baseRevisionFiles = baseRevision.getChartTemplatesList();
        const headRevisionFiles = headRevision.getChartTemplatesList();
        const diffArray = [];
        return Promise.resolve()
            .then(() => {
                // find all diff in both revision files
                return Promise.map(baseRevisionFiles, (file) => {
                    const headFile = headRevisionFiles.find((headFile) => headFile.name === file.name);
                    if (headFile) {
                        const baseFileDecodedToString = Buffer.from(file.data, 'base64').toString();
                        const headFileDecodedToString = Buffer.from(headFile.data, 'base64').toString();
                        diffArray.push({
                            from: headFile.name,
                            head: headFileDecodedToString,
                            base: baseFileDecodedToString,
                        });
                    }
                });
            })
            .then(() => {
                // find all the new files in head
                return Promise.map(headRevisionFiles, (file) => {
                    const name = file.name;
                    const isDiffExist = diffArray.find(f => f.from === name);
                    if (!isDiffExist) {
                        diffArray.push({
                            from: name,
                            head: headFileDecodedToString,
                            diff: diffLines('', headFileDecodedToString) 
                        });
                    }
                });
            })
            .then(() => diffArray);
    }
}

module.exports = Release;
